==> huaweicloudsdkcbr-3.0.47-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/copy_backup_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class CopyBackupResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'replication': 'BackupReplicateRespBody'
    }

    attribute_map = {
        'replication': 'replication'
    }

    def __init__(self, replication=None):
        """CopyBackupResponse - a model defined in huaweicloud sdk"""
        
        super(CopyBackupResponse, self).__init__()

        self._replication = None
        self.discriminator = None

        if replication is not None:
            self.replication = replication

    @property
    def replication(self):
        """Gets the replication of this CopyBackupResponse.


        :return: The replication of this CopyBackupResponse.
        :rtype: BackupReplicateRespBody
        """
        return self._replication

    @replication.setter
    def replication(self, replication):
        """Sets the replication of this CopyBackupResponse.


        :param replication: The replication of this CopyBackupResponse.
        :type: BackupReplicateRespBody
        """
        self._replication = replication

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CopyBackupResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcbr-3.0.51-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/copy_backup_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class CopyBackupResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'replication': 'BackupReplicateRespBody'
    }

    attribute_map = {
        'replication': 'replication'
    }

    def __init__(self, replication=None):
        """CopyBackupResponse - a model defined in huaweicloud sdk"""
        
        super(CopyBackupResponse, self).__init__()

        self._replication = None
        self.discriminator = None

        if replication is not None:
            self.replication = replication

    @property
    def replication(self):
        """Gets the replication of this CopyBackupResponse.


        :return: The replication of this CopyBackupResponse.
        :rtype: BackupReplicateRespBody
        """
        return self._replication

    @replication.setter
    def replication(self, replication):
        """Sets the replication of this CopyBackupResponse.


        :param replication: The replication of this CopyBackupResponse.
        :type: BackupReplicateRespBody
        """
        self._replication = replication

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CopyBackupResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
